"""
NiaHub — Networked Interaction Architecture Hub
Minimal seed release to reserve the name and provide a tiny API.
"""

from .core import hello

__all__ = ["hello", "__version__"]
__version__ = "0.0.1"
